﻿<#	
	===========================================================================
	 Created on:   	1/11/2019 10:28
	 Created by:   	jisodl0
	 Organization: 	J.B. Hunt
	 Filename:     	Artemis.psm1
	-------------------------------------------------------------------------
	 Module Name: Artemis
	===========================================================================
#>
<#
	.SYNOPSIS
		Restart a service used by J.B. Hunt.
	
	.DESCRIPTION
		Restarts the given service on the given computer so long as you have the necessary permissions. This is done by retrieving the service from the given computer name, stopping that service, then starting it back up. Each step requires confirmation before continuing to the next to avoid any issues.
	
	.PARAMETER ServiceName
		A description of the ServiceName parameter.
	
	.PARAMETER ComputerName
		The name of the computer/server to restart the given service on. Defaults to the local machine if no value is provided.
	
	.EXAMPLE
				PS C:\> Restart-JBService -ServiceName 'Value1'
	
	.NOTES
		Additional information about the function.
#>

function Restart-JBService {
	[CmdletBinding(PositionalBinding = $true)]
	param (
		[Parameter(Mandatory = $true,
				   Position = 0)]
		[Alias('Name', 'Service')]
		[System.String]
		$ServiceName,
		
		[Parameter(Position = 1,
				   HelpMessage = 'Which computer would you like to reset the service on?')]
		[Alias('Computer', 'ServerName', 'Server')]
		[System.String]
		$ComputerName = $env:COMPUTERNAME
	)
	
	$Service = Get-Service -Name $ServiceName -ComputerName $env:COMPUTERNAME
	if ($Service.Length -gt 1) {
		for ($x = 0; $x -lt $Service.Length; $x++) {
			$Name = $Service[$x].Name
			$Status = $Service[$x].Status

			Write-Host "$x" -ForegroundColor Yellow -NoNewline
			Write-Host " - $Name - " -ForegroundColor White -NoNewline

			switch ($Status) {
				'Stopped' {
					Write-Host "$Status" -ForegroundColor Red
				}
				'Running' {
					Write-Host "$Status" -ForegroundColor Green
				}
			}
		}
	} else {
		$CorrS = Get-CorrectService
		
		if ($CorrS.StartsWith('y') -or ($CorrS.Length -eq 0)) {
			Stop-Service $Service
			$ContFlag = Get-ContinueFlag
			
			if ($ContFlag.StartsWith('y') -or ($ContFlag.Length -eq 0)) {
				Start-Service $Service
			}
		}
	}
}

function Get-CorrectService {
	$CorrectService = Read-Host -Prompt 'Is this the correct service? (Y/N)'
	
	if ($CorrectService.Length -gt 0) {
		return $CorrectService.ToLower()
	} else {
		return $CorrectService
	}
}

function Get-ContinueFlag {
	$Continue = Read-Host -Prompt 'Continue with restart? (Y/N)'
	
	if ($Continue.Length -gt 0) {
		return $Continue.ToLower()
	} else {
		return $Continue
	}
}
